pub enum CmdType {
Any,
Graphics,
Transfer,
Compute,
}Expand description
Abstraction over queue capability and command types since dedicated queues may not be available.
get_queue will fallback to the guarenteed unified queue if necessary.
let init = VkInit::new(Some(window_options), create_info)?;
let (compute_queue, compute_queue_family_index) = init.get_queue(CmdType::Compute);Variants